@@ -3,21 +3,20 @@ use serde::{Deserialize, Serialize};
 
 use crate::tokens::TokensHuman;
 use cosmwasm_bignumber::{Decimal256, Uint256};
-use cosmwasm_std::HumanAddr;
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 #[serde(rename_all = "snake_case")]
-pub struct InitMsg {
+pub struct InstantiateMsg {
     /// Initial owner address
-    pub owner_addr: HumanAddr,
+    pub owner_addr: String,
     /// Oracle contract address for collateral tokens
-    pub oracle_contract: HumanAddr,
+    pub oracle_contract: String,
     /// Market contract address to receive missing interest buffer
-    pub market_contract: HumanAddr,
+    pub market_contract: String,
     /// Liquidation model contract address to compute liquidation amount
-    pub liquidation_contract: HumanAddr,
+    pub liquidation_contract: String,
     /// Collector contract address which is purchasing ANC token
-    pub collector_contract: HumanAddr,
+    pub collector_contract: String,
     /// The base denomination used when fetching oracle price,
     /// reward distribution, and borrow
     pub stable_denom: String,
@@ -40,16 +39,16 @@ pub struct InitMsg {
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 #[serde(rename_all = "snake_case")]
-pub enum HandleMsg {
+pub enum ExecuteMsg {
     ////////////////////
     /// Owner operations
     ////////////////////
 
     /// Update Configs
     UpdateConfig {
-        owner_addr: Option<HumanAddr>,
-        oracle_contract: Option<HumanAddr>,
-        liquidation_contract: Option<HumanAddr>,
+        owner_addr: Option<String>,
+        oracle_contract: Option<String>,
+        liquidation_contract: Option<String>,
         threshold_deposit_rate: Option<Decimal256>,
         target_deposit_rate: Option<Decimal256>,
         buffer_distribution_factor: Option<Decimal256>,
@@ -60,17 +59,17 @@ pub enum HandleMsg {
 
     /// Create new custody contract for the given collateral token
     Whitelist {
-        name: String,                // bAsset name
-        symbol: String,              // bAsset symbol
-        collateral_token: HumanAddr, // bAsset token contract
-        custody_contract: HumanAddr, // bAsset custody contract
-        max_ltv: Decimal256,         // Loan To Value ratio
+        name: String,             // bAsset name
+        symbol: String,           // bAsset symbol
+        collateral_token: String, // bAsset token contract
+        custody_contract: String, // bAsset custody contract
+        max_ltv: Decimal256,      // Loan To Value ratio
     },
     /// Update registered whitelist info
     UpdateWhitelist {
-        collateral_token: HumanAddr,         // bAsset token contract
-        custody_contract: Option<HumanAddr>, // bAsset custody contract
-        max_ltv: Option<Decimal256>,         // Loan To Value ratio
+        collateral_token: String,         // bAsset token contract
+        custody_contract: Option<String>, // bAsset custody contract
+        max_ltv: Option<Decimal256>,      // Loan To Value ratio
     },
 
     /// Claims all staking rewards from the bAsset contracts
@@ -97,7 +96,7 @@ pub enum HandleMsg {
     /////////////////////////////
     /// Permissionless operations
     /////////////////////////////
-    LiquidateCollateral { borrower: HumanAddr },
+    LiquidateCollateral { borrower: String },
 }
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
@@ -106,19 +105,19 @@ pub enum QueryMsg {
     Config {},
     EpochState {},
     Whitelist {
-        collateral_token: Option<HumanAddr>,
-        start_after: Option<HumanAddr>,
+        collateral_token: Option<String>,
+        start_after: Option<String>,
         limit: Option<u32>,
     },
     Collaterals {
-        borrower: HumanAddr,
+        borrower: String,
     },
     AllCollaterals {
-        start_after: Option<HumanAddr>,
+        start_after: Option<String>,
         limit: Option<u32>,
     },
     BorrowLimit {
-        borrower: HumanAddr,
+        borrower: String,
         block_time: Option<u64>,
     },
 }
@@ -126,11 +125,11 @@ pub enum QueryMsg {
 // We define a custom struct for each query response
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct ConfigResponse {
-    pub owner_addr: HumanAddr,
-    pub oracle_contract: HumanAddr,
-    pub market_contract: HumanAddr,
-    pub liquidation_contract: HumanAddr,
-    pub collector_contract: HumanAddr,
+    pub owner_addr: String,
+    pub oracle_contract: String,
+    pub market_contract: String,
+    pub liquidation_contract: String,
+    pub collector_contract: String,
     pub threshold_deposit_rate: Decimal256,
     pub target_deposit_rate: Decimal256,
     pub buffer_distribution_factor: Decimal256,
@@ -146,8 +145,8 @@ pub struct WhitelistResponseElem {
     pub name: String,
     pub symbol: String,
     pub max_ltv: Decimal256,
-    pub custody_contract: HumanAddr,
-    pub collateral_token: HumanAddr,
+    pub custody_contract: String,
+    pub collateral_token: String,
 }
 
 // We define a custom struct for each query response
@@ -159,7 +158,7 @@ pub struct WhitelistResponse {
 // We define a custom struct for each query response
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct CollateralsResponse {
-    pub borrower: HumanAddr,
+    pub borrower: String,
     pub collaterals: TokensHuman, // <(Collateral Token, Amount)>
 }
 
@@ -171,13 +170,6 @@ pub struct AllCollateralsResponse {
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct BorrowLimitResponse {
-    pub borrower: HumanAddr,
+    pub borrower: String,
     pub borrow_limit: Uint256,
 }
-
-#[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
-#[serde(rename_all = "snake_case")]
-pub struct MigrateMsg {
-    pub target_deposit_rate: Decimal256,
-    pub threshold_deposit_rate: Decimal256,
-}
